@@ -64,6 +64,13 @@ func TestDesiredDNSDaemonset(t *testing.T) {
 	}
 }
 
+var toleration = corev1.Toleration{
+	Key:      "foo",
+	Value:    "bar",
+	Operator: corev1.TolerationOpExists,
+	Effect:   corev1.TaintEffectNoExecute,
+}
+
 func TestDaemonsetConfigChanged(t *testing.T) {
 	testCases := []struct {
 		description string
@@ -90,6 +97,13 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 			},
 			expect: true,
 		},
+		{
+			description: "if .spec.template.spec.tolerations changes",
+			mutate: func(daemonset *appsv1.DaemonSet) {
+				daemonset.Spec.Template.Spec.Tolerations = []corev1.Toleration{toleration}
+			},
+			expect: true,
+		},
 		{
 			description: "if the dns-node-resolver container image is changed",
 			mutate: func(daemonset *appsv1.DaemonSet) {
